
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.002005
eval "use Test::Spelling 0.12; use Pod::Wordlist::hanekomu; 1" or die $@;


add_stopwords(<DATA>);
all_pod_files_spelling_ok('bin', 'lib');
__DATA__
CyberSource's
Num
Str
datetime
merchantID
ip
cid
cvn
cvc
cvv
login
SOAPI
Bleue
Carta
Carte
Dankort
JAL
Santander
UATP
YYYY
timestamp
overmeer
AVS
MerchantReferenceCode
env
WSDL
XSD
subclasses
auth
dcc
Caleb
Cushing
HostGator
lib
Business
CyberSource
RequestPart
Service
AuthReversal
Response
Role
ReasonCode
Message
Factory
Request
Currency
Capture
Rule
RequestIDisZero
ResponsePart
TaxReply
Item
BusinessRules
Authorization
DCCReply
CVN
ProcessorResponse
ReconciliationID
BillTo
DCC
StandAloneCredit
FollowOnCredit
Client
RequestDateTime
Credit
Reply
TaxService
Amount
PurchaseTotals
MooseX
Types
AuthReply
ExpiredCard
Tax
BillingInfo
Accept
Card
CreditCardInfo
ForeignCurrency
Sale
MessagePart
